Accepting request 1084536 from Java:packages

3.9.1

OBS-URL: https://build.opensuse.org/request/show/1084536
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/maven?expand=0&rev=15
This commit is contained in:
Dominique Leuenberger 2023-05-04 15:10:14 +00:00 committed by Git OBS Bridge
commit d22b31648a
14 changed files with 358 additions and 428 deletions

View File

@ -1,14 +1,14 @@
From 6e8f6a1b27c09d0a84fb5f3b7269cf5840db04f8 Mon Sep 17 00:00:00 2001
From 8d6b4651e2be6156322d27d7c8715601a6b11cd2 Mon Sep 17 00:00:00 2001
From: Michael Simacek <msimacek@redhat.com>
Date: Wed, 1 Feb 2017 14:54:26 +0100
Subject: [PATCH 1/7] Adapt mvn script
Subject: [PATCH 1/4] Adapt mvn script
---
apache-maven/src/bin/mvn | 19 ++++++++++++++++---
1 file changed, 16 insertions(+), 3 deletions(-)
apache-maven/src/bin/mvn | 17 ++++++++++-------
1 file changed, 10 insertions(+), 7 deletions(-)
diff --git a/apache-maven/src/bin/mvn b/apache-maven/src/bin/mvn
index dfa384b8e..8c03825ed 100755
index a3004f917..052df8f0c 100755
--- a/apache-maven/src/bin/mvn
+++ b/apache-maven/src/bin/mvn
@@ -22,7 +22,7 @@
@ -17,14 +17,22 @@ index dfa384b8e..8c03825ed 100755
#
-# JAVA_HOME Must point at your Java Development Kit installation.
+# JAVA_HOME (Optional) Must point at your Java Development Kit installation.
# MAVEN_ARGS (Optional) Arguments passed to Maven before CLI arguments.
# MAVEN_OPTS (Optional) Java runtime options used when Maven is executed.
# MAVEN_SKIP_RC (Optional) Flag to disable loading of mavenrc files.
# -----------------------------------------------------------------------------
@@ -37,12 +37,24 @@ if [ -z "$MAVEN_SKIP_RC" ] ; then
@@ -30,20 +30,22 @@
if [ -z "$MAVEN_SKIP_RC" ] ; then
- if [ -f /usr/local/etc/mavenrc ] ; then
- . /usr/local/etc/mavenrc
- fi
-
if [ -f /etc/mavenrc ] ; then
. /etc/mavenrc
fi
+ if [ -f /etc/java/maven.conf ] ; then
+ if [ -z "$JAVA_HOME" ] ; then
+ . /etc/java/maven.conf
+ fi
+
@ -34,18 +42,12 @@ index dfa384b8e..8c03825ed 100755
fi
+if [ -f /usr/share/java-utils/java-functions ] ; then
+ . /usr/share/java-utils/java-functions
+ set_jvm
+ set_javacmd
+fi
+export JAVA_HOME
+export JAVACMD
+
# OS specific support. $var _must_ be set to either true or false.
cygwin=false;
mingw=false;
@@ -67,7 +79,8 @@ done
@@ -68,7 +70,8 @@ done
saveddir=`pwd`
@ -55,7 +57,7 @@ index dfa384b8e..8c03825ed 100755
# make it fully qualified
MAVEN_HOME=`cd "$MAVEN_HOME" && pwd`
@@ -105,7 +118,7 @@ if [ ! -x "$JAVACMD" ] ; then
@@ -106,7 +109,7 @@ if [ ! -x "$JAVACMD" ] ; then
exit 1
fi
@ -65,5 +67,5 @@ index dfa384b8e..8c03825ed 100755
# For Cygwin, switch paths to Windows format before running java
--
2.36.1
2.40.1

View File

@ -1,53 +1,51 @@
From 4d259917ec0a1e73a9bbf23e0737acd64727b802 Mon Sep 17 00:00:00 2001
From d1e6e9bcce8553e85957987d05d28583fcb55fdf Mon Sep 17 00:00:00 2001
From: Michael Simacek <msimacek@redhat.com>
Date: Tue, 6 Jun 2017 13:47:43 +0200
Subject: [PATCH 2/7] Invoke logback via reflection
Subject: [PATCH 2/4] Invoke logback via reflection
---
.../logging/impl/LogbackConfiguration.java | 19 ++++++++++++++-----
1 file changed, 14 insertions(+), 5 deletions(-)
.../cli/logging/impl/LogbackConfiguration.java | 18 +++++++++++++-----
1 file changed, 13 insertions(+), 5 deletions(-)
diff --git a/maven-embedder/src/main/java/org/apache/maven/cli/logging/impl/LogbackConfiguration.java b/maven-embedder/src/main/java/org/apache/maven/cli/logging/impl/LogbackConfiguration.java
index 5d9fab744..ced38cb5a 100644
index 4dc5a37b8..a977ba085 100644
--- a/maven-embedder/src/main/java/org/apache/maven/cli/logging/impl/LogbackConfiguration.java
+++ b/maven-embedder/src/main/java/org/apache/maven/cli/logging/impl/LogbackConfiguration.java
@@ -35,22 +35,31 @@
@Override
public void setRootLoggerLevel( Level level )
{
- ch.qos.logback.classic.Level value;
+ String value;
switch ( level )
{
case DEBUG:
- value = ch.qos.logback.classic.Level.DEBUG;
+ value = "DEBUG";
break;
case INFO:
- value = ch.qos.logback.classic.Level.INFO;
+ value = "INFO";
break;
default:
- value = ch.qos.logback.classic.Level.ERROR;
+ value = "ERROR";
break;
}
- ( (ch.qos.logback.classic.Logger) LoggerFactory.getLogger( Logger.ROOT_LOGGER_NAME ) ).setLevel( value );
+ Logger logger = LoggerFactory.getLogger( Logger.ROOT_LOGGER_NAME );
+ try {
+ Class<?> levelClass = Class.forName("ch.qos.logback.classic.Level");
+ Object logbackLevel = levelClass.getField(value).get(null);
+ Class<?> loggerClass = Class.forName("ch.qos.logback.classic.Logger");
+ loggerClass.getMethod("setLevel", new Class<?>[] {levelClass})
+ .invoke(logger, new Object[] {logbackLevel});
+ } catch (Exception e) {
+ throw new RuntimeException("Failed to initialize logback configuration", e);
+ }
}
@Override
@@ -31,21 +31,29 @@
public class LogbackConfiguration extends BaseSlf4jConfiguration {
@Override
public void setRootLoggerLevel(Level level) {
- ch.qos.logback.classic.Level value;
+ String value;
switch (level) {
case DEBUG:
- value = ch.qos.logback.classic.Level.DEBUG;
+ value = "DEBUG";
break;
case INFO:
- value = ch.qos.logback.classic.Level.INFO;
+ value = "INFO";
break;
default:
- value = ch.qos.logback.classic.Level.ERROR;
+ value = "ERROR";
break;
}
- ((ch.qos.logback.classic.Logger) LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME)).setLevel(value);
+ Logger logger = LoggerFactory.getLogger(Logger.ROOT_LOGGER_NAME);
+ try {
+ Class<?> levelClass = Class.forName("ch.qos.logback.classic.Level");
+ Object logbackLevel = levelClass.getField(value).get(null);
+ Class<?> loggerClass = Class.forName("ch.qos.logback.classic.Logger");
+ loggerClass.getMethod("setLevel", new Class<?>[] {levelClass}).invoke(logger, new Object[] {logbackLevel});
+ } catch (Exception e) {
+ throw new RuntimeException("Failed to initialize logback configuration", e);
+ }
}
@Override
--
2.36.1
2.40.1

View File

@ -0,0 +1,89 @@
From fdc9034faeb960d15aa39820d610e00cd7121e03 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Thu, 5 Sep 2019 15:21:04 +0200
Subject: [PATCH 3/4] Remove dependency on powermock
---
.../StringSearchModelInterpolatorTest.java | 59 -------------------
1 file changed, 59 deletions(-)
diff --git a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
index b2612e540..20b7162e2 100644
--- a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
+++ b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
@@ -35,8 +35,6 @@
import static org.hamcrest.CoreMatchers.anyOf;
import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;
-import static org.powermock.reflect.Whitebox.getField;
-import static org.powermock.reflect.Whitebox.getInternalState;
/**
* @author jdcasey
@@ -344,63 +342,6 @@ public void testInterpolateObjectWithPomFile() throws Exception {
is(System.getProperty("user.dir") + File.separator + '.' + File.separator + "target"))));
}
- public void testNotInterpolateObjectWithFile() throws Exception {
- Model model = new Model();
-
- File baseDir = new File(System.getProperty("user.dir"));
-
- Properties p = new Properties();
-
- ObjectWithNotInterpolatedFile obj = new ObjectWithNotInterpolatedFile(baseDir);
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest(p);
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject(obj, model, new File("."), config, collector);
- assertProblemFree(collector);
-
- //noinspection unchecked
- Map<Class<?>, ?> cache = (Map<Class<?>, ?>)
- getField(StringSearchModelInterpolator.class, "CACHED_ENTRIES").get(null);
-
- Object objCacheItem = cache.get(Object.class);
- Object fileCacheItem = cache.get(File.class);
-
- assertNotNull(objCacheItem);
- assertNotNull(fileCacheItem);
-
- assertThat(((Object[]) getInternalState(objCacheItem, "fields")).length, is(0));
- assertThat(((Object[]) getInternalState(fileCacheItem, "fields")).length, is(0));
- }
-
- public void testNotInterpolateFile() throws Exception {
- Model model = new Model();
-
- File baseDir = new File(System.getProperty("user.dir"));
-
- Properties p = new Properties();
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest(p);
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject(baseDir, model, new File("."), config, collector);
- assertProblemFree(collector);
-
- //noinspection unchecked
- Map<Class<?>, ?> cache = (Map<Class<?>, ?>)
- getField(StringSearchModelInterpolator.class, "CACHED_ENTRIES").get(null);
-
- Object fileCacheItem = cache.get(File.class);
-
- assertNotNull(fileCacheItem);
-
- assertThat(((Object[]) getInternalState(fileCacheItem, "fields")).length, is(0));
- }
-
public void testConcurrentInterpolation() throws Exception {
final Model model = new Model();
--
2.40.1

View File

@ -1,51 +0,0 @@
From 507d1090563596d0752918ec3572a8c4a4130d2b Mon Sep 17 00:00:00 2001
From: Mikolaj Izdebski <mizdebsk@redhat.com>
Date: Mon, 1 Jul 2019 09:51:56 +0200
Subject: [PATCH 3/7] Use non-shaded HTTP wagon
---
apache-maven/pom.xml | 15 ---------------
pom.xml | 1 -
2 files changed, 16 deletions(-)
diff --git a/apache-maven/pom.xml b/apache-maven/pom.xml
index 7ff412767..b15091576 100644
--- a/apache-maven/pom.xml
+++ b/apache-maven/pom.xml
@@ -63,21 +63,6 @@ under the License.
<dependency>
<groupId>org.apache.maven.wagon</groupId>
<artifactId>wagon-http</artifactId>
- <classifier>shaded</classifier>
- <exclusions>
- <exclusion>
- <groupId>org.apache.httpcomponents</groupId>
- <artifactId>httpclient</artifactId>
- </exclusion>
- <exclusion>
- <groupId>org.apache.httpcomponents</groupId>
- <artifactId>httpcore</artifactId>
- </exclusion>
- <exclusion>
- <groupId>org.apache.maven.wagon</groupId>
- <artifactId>wagon-http-shared</artifactId>
- </exclusion>
- </exclusions>
</dependency>
<dependency>
<groupId>org.slf4j</groupId>
diff --git a/pom.xml b/pom.xml
index c319cae26..42afab5f1 100644
--- a/pom.xml
+++ b/pom.xml
@@ -333,7 +333,6 @@ under the License.
<groupId>org.apache.maven.wagon</groupId>
<artifactId>wagon-http</artifactId>
<version>${wagonVersion}</version>
- <classifier>shaded</classifier>
<exclusions>
<exclusion>
<groupId>commons-logging</groupId>
--
2.36.1

View File

@ -1,7 +1,7 @@
From c8ecbea0dd63d065376768e8cae571a15aa48ae8 Mon Sep 17 00:00:00 2001
From a46e8cb4641508c71379a07869551c770f18f1b9 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Fridrich=20=C5=A0trba?= <fridrich.strba@bluewin.ch>
Date: Fri, 13 May 2022 17:34:20 +0200
Subject: [PATCH 7/7] Fix build with qdox-2.0.1
Date: Tue, 2 May 2023 18:12:26 +0200
Subject: [PATCH 4/4] Fix build with qdox-2.0.1
---
.../org/apache/maven/plugin/DefaultExtensionRealmCache.java | 2 +-
@ -11,148 +11,146 @@ Subject: [PATCH 7/7] Fix build with qdox-2.0.1
.../java/org/apache/maven/plugin/PluginArtifactsCache.java | 4 ++--
.../main/java/org/apache/maven/plugin/PluginRealmCache.java | 4 ++--
.../org/apache/maven/project/DefaultProjectRealmCache.java | 2 +-
.../main/java/org/apache/maven/project/ProjectRealmCache.java | 2 +-
.../main/java/org/apache/maven/project/ProjectRealmCache.java | 4 ++--
.../maven/project/artifact/DefaultProjectArtifactsCache.java | 2 +-
.../apache/maven/project/artifact/ProjectArtifactsCache.java | 4 ++--
10 files changed, 14 insertions(+), 14 deletions(-)
10 files changed, 15 insertions(+), 15 deletions(-)
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
index 6ce63ebbf..e3241c070 100644
index e2b712305..ce7bcae4e 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultExtensionRealmCache.java
@@ -157,7 +157,7 @@ public void flush()
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track extension usage
}
@@ -138,7 +138,7 @@ public void flush() {
cache.clear();
}
- public void register(MavenProject project, Key key, CacheRecord record) {
+ public void register(MavenProject project, Key key, CacheRecord record_) {
// default cache does not track extension usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
index ee11c4c89..2adb29369 100644
index f2088b593..e5d7244fd 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginArtifactsCache.java
@@ -198,7 +198,7 @@ protected static boolean pluginEquals( Plugin a, Plugin b )
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
@@ -177,7 +177,7 @@ protected static boolean pluginEquals(Plugin a, Plugin b) {
return CacheUtils.pluginEquals(a, b);
}
- public void register(MavenProject project, Key cacheKey, CacheRecord record) {
+ public void register(MavenProject project, Key cacheKey, CacheRecord record_) {
// default cache does not track record usage
}
}
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
index 7862b40de..9432d307f 100644
index 10321374b..c9e1d0e59 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/DefaultPluginRealmCache.java
@@ -200,7 +200,7 @@ protected static boolean pluginEquals( Plugin a, Plugin b )
return CacheUtils.pluginEquals( a, b );
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track plugin usage
}
@@ -204,7 +204,7 @@ protected static boolean pluginEquals(Plugin a, Plugin b) {
return CacheUtils.pluginEquals(a, b);
}
- public void register(MavenProject project, Key key, CacheRecord record) {
+ public void register(MavenProject project, Key key, CacheRecord record_) {
// default cache does not track plugin usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java b/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
index a7f06156a..c74fd644f 100644
index 1a1f70638..cb446c759 100644
--- a/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/DefaultProjectRealmCache.java
@@ -135,7 +135,7 @@ public void flush()
cache.clear();
}
- public void register( MavenProject project, Key key, CacheRecord record )
+ public void register( MavenProject project, Key key, CacheRecord record_ )
{
// default cache does not track record usage
}
@@ -115,7 +115,7 @@ public void flush() {
cache.clear();
}
- public void register(MavenProject project, Key key, CacheRecord record) {
+ public void register(MavenProject project, Key key, CacheRecord record_) {
// default cache does not track record usage
}
diff --git a/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
index ae59ada4d..83b1b4333 100644
index c45128530..a854fd234 100644
--- a/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/artifact/DefaultProjectArtifactsCache.java
@@ -240,7 +240,7 @@ public void flush()
}
@Override
- public void register( MavenProject project, Key cacheKey, CacheRecord record )
+ public void register( MavenProject project, Key cacheKey, CacheRecord record_ )
{
// default cache does not track record usage
}
@@ -227,7 +227,7 @@ public void flush() {
}
@Override
- public void register(MavenProject project, Key cacheKey, CacheRecord record) {
+ public void register(MavenProject project, Key cacheKey, CacheRecord record_) {
// default cache does not track record usage
}
}
--
2.36.1
@@ -93,7 +93,7 @@ Key createKey(
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
- void register(MavenProject project, Key cacheKey, CacheRecord record);
+ void register(MavenProject project, Key cacheKey, CacheRecord record_);
}
--
2.40.1

View File

@ -1,96 +0,0 @@
From 710c46095ed8b34c0cb7c2e69379db044eb026e9 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Thu, 5 Sep 2019 15:21:04 +0200
Subject: [PATCH 4/7] Remove dependency on powermock
---
.../StringSearchModelInterpolatorTest.java | 66 -------------------
1 file changed, 66 deletions(-)
diff --git a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
index c95e37271..aafafa52f 100644
--- a/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
+++ b/maven-model-builder/src/test/java/org/apache/maven/model/interpolation/StringSearchModelInterpolatorTest.java
@@ -36,8 +36,6 @@
import static org.hamcrest.CoreMatchers.anyOf;
import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;
-import static org.powermock.reflect.Whitebox.getField;
-import static org.powermock.reflect.Whitebox.getInternalState;
/**
* @author jdcasey
@@ -375,70 +373,6 @@ public void testInterpolateObjectWithPomFile()
) ) );
}
- public void testNotInterpolateObjectWithFile()
- throws Exception
- {
- Model model = new Model();
-
- File baseDir = new File( System.getProperty( "user.dir" ) );
-
- Properties p = new Properties();
-
- ObjectWithNotInterpolatedFile obj = new ObjectWithNotInterpolatedFile( baseDir );
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest( p );
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject( obj, model, new File( "." ), config, collector );
- assertProblemFree( collector );
-
- //noinspection unchecked
- Map<Class<?>, ?> cache =
- (Map<Class<?>, ?>) getField( StringSearchModelInterpolator.class, "CACHED_ENTRIES" )
- .get( null );
-
- Object objCacheItem = cache.get( Object.class );
- Object fileCacheItem = cache.get( File.class );
-
- assertNotNull( objCacheItem );
- assertNotNull( fileCacheItem );
-
- assertThat( ( (Object[]) getInternalState( objCacheItem, "fields" ) ).length, is( 0 ) );
- assertThat( ( (Object[]) getInternalState( fileCacheItem, "fields" ) ).length, is( 0 ) );
- }
-
- public void testNotInterpolateFile()
- throws Exception
- {
- Model model = new Model();
-
- File baseDir = new File( System.getProperty( "user.dir" ) );
-
- Properties p = new Properties();
-
- StringSearchModelInterpolator interpolator = (StringSearchModelInterpolator) createInterpolator();
-
- ModelBuildingRequest config = createModelBuildingRequest( p );
-
- SimpleProblemCollector collector = new SimpleProblemCollector();
- interpolator.interpolateObject( baseDir, model, new File( "." ), config, collector );
- assertProblemFree( collector );
-
- //noinspection unchecked
- Map<Class<?>, ?> cache =
- (Map<Class<?>, ?>) getField( StringSearchModelInterpolator.class, "CACHED_ENTRIES" )
- .get( null );
-
- Object fileCacheItem = cache.get( File.class );
-
- assertNotNull( fileCacheItem );
-
- assertThat( ( (Object[]) getInternalState( fileCacheItem, "fields" ) ).length, is( 0 ) );
- }
-
-
public void testConcurrentInterpolation()
throws Exception
{
--
2.36.1

View File

@ -1,25 +0,0 @@
From 64c73b39d35ac08666cb1f1eb0be26150bf4a821 Mon Sep 17 00:00:00 2001
From: Marian Koncek <mkoncek@redhat.com>
Date: Fri, 17 Dec 2021 13:05:49 +0100
Subject: [PATCH 5/7] Port to maven-resolver 1.7.2
---
.../org/apache/maven/repository/internal/MavenAetherModule.java | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
index 41e98aaea..d72e3c0f3 100644
--- a/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
+++ b/maven-resolver-provider/src/main/java/org/apache/maven/repository/internal/MavenAetherModule.java
@@ -28,7 +28,7 @@
import org.apache.maven.model.building.DefaultModelBuilderFactory;
import org.apache.maven.model.building.ModelBuilder;
-import org.eclipse.aether.impl.AetherModule;
+import org.eclipse.aether.impl.guice.AetherModule;
import org.eclipse.aether.impl.ArtifactDescriptorReader;
import org.eclipse.aether.impl.MetadataGeneratorFactory;
import org.eclipse.aether.impl.VersionRangeResolver;
--
2.36.1

View File

@ -1,37 +0,0 @@
From 8b9a2cb2879012dfa2e666a6c33be183da532d47 Mon Sep 17 00:00:00 2001
From: Mikolaj Izdebski <mizdebsk@redhat.com>
Date: Fri, 22 Apr 2022 11:15:38 +0200
Subject: [PATCH 6/7] Restore DefaultModelValidator compatibility with Maven
3.5.4
---
.../maven/model/validation/DefaultModelValidator.java | 6 ++++++
1 file changed, 6 insertions(+)
diff --git a/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java b/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
index f77321c16..4ed22f3ed 100644
--- a/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
+++ b/maven-model-builder/src/main/java/org/apache/maven/model/validation/DefaultModelValidator.java
@@ -44,6 +44,7 @@
import org.apache.maven.model.building.ModelProblem.Version;
import org.apache.maven.model.building.ModelProblemCollector;
import org.apache.maven.model.building.ModelProblemCollectorRequest;
+import org.apache.maven.model.interpolation.DefaultModelVersionProcessor;
import org.apache.maven.model.interpolation.ModelVersionProcessor;
import org.codehaus.plexus.util.StringUtils;
@@ -85,6 +86,11 @@
private ModelVersionProcessor versionProcessor;
+ public DefaultModelValidator()
+ {
+ this( new DefaultModelVersionProcessor() );
+ }
+
@Inject
public DefaultModelValidator( ModelVersionProcessor versionProcessor )
{
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
index 4d01aca4f..c0fda73c6 100644
index 022b99320..b5cb6e66a 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/ExtensionRealmCache.java
@@ -94,8 +94,8 @@ CacheRecord put( Key key, ClassRealm extensionRealm, ExtensionDescriptor extensi
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -86,7 +86,7 @@ CacheRecord put(
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register(MavenProject project, Key key, CacheRecord record);
+ void register(MavenProject project, Key key, CacheRecord record_);
}
@@ -94,8 +94,8 @@ CacheRecord put( Key key, ClassRealm extensionRealm, ExtensionDescriptor extensi
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
@@ -86,7 +86,7 @@ CacheRecord put(
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
index 11f5d701f..cf17fe3d8 100644
index b0c07ae9a..97f76524c 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/PluginArtifactsCache.java
@@ -97,8 +97,8 @@ Key createKey( Plugin plugin, DependencyFilter extensionFilter, List<RemoteRepos
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -92,7 +92,7 @@ Key createKey(
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register(MavenProject project, Key cacheKey, CacheRecord record);
+ void register(MavenProject project, Key cacheKey, CacheRecord record_);
}
@@ -97,8 +97,8 @@ Key createKey( Plugin plugin, DependencyFilter extensionFilter, List<RemoteRepos
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
@@ -92,7 +92,7 @@ Key createKey(
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java b/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
index 78c3ae6f3..f4aa66f78 100644
index bf655efc3..7b0e25259 100644
--- a/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/plugin/PluginRealmCache.java
@@ -90,8 +90,8 @@ Key createKey( Plugin plugin, ClassLoader parentRealm, Map<String, ClassLoader>
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -102,7 +102,7 @@ default CacheRecord get(Key key, PluginRealmSupplier supplier)
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register(MavenProject project, Key key, CacheRecord record);
+ void register(MavenProject project, Key key, CacheRecord record_);
}
@@ -90,8 +90,8 @@ Key createKey( Plugin plugin, ClassLoader parentRealm, Map<String, ClassLoader>
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
@@ -102,7 +102,7 @@ default CacheRecord get(Key key, PluginRealmSupplier supplier)
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java b/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
index 28ac0d620..72d4002c6 100644
index 241c86095..922ec982c 100644
--- a/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/ProjectRealmCache.java
@@ -87,6 +87,6 @@ public DependencyFilter getExtensionArtifactFilter()
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key key, CacheRecord record );
+ void register( MavenProject project, Key key, CacheRecord record_ );
}
@@ -77,7 +77,7 @@ public DependencyFilter getExtensionArtifactFilter() {
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register(MavenProject project, Key key, CacheRecord record);
+ void register(MavenProject project, Key key, CacheRecord record_);
}
@@ -77,7 +77,7 @@ public DependencyFilter getExtensionArtifactFilter() {
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
diff --git a/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java b/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
index 8d8ad790e..690392da5 100644
index 025800698..f6ba70b86 100644
--- a/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
+++ b/maven-core/src/main/java/org/apache/maven/project/artifact/ProjectArtifactsCache.java
@@ -96,8 +96,8 @@ Key createKey( MavenProject project, Collection<String> scopesToCollect, Collect
* cache.
*
* @param project The project that employs the plugin realm, must not be {@code null}.
* @param record The cache record being used for the project, must not be {@code null}.
*/
- void register( MavenProject project, Key cacheKey, CacheRecord record );
+ void register( MavenProject project, Key cacheKey, CacheRecord record_ );
}
@@ -96,8 +96,8 @@ Key createKey( MavenProject project, Collection<String> scopesToCollect, Collect
*
* @param project The project that employs the plugin realm, must not be {@code null}.
- * @param record The cache record being used for the project, must not be {@code null}.
+ * @param record_ The cache record being used for the project, must not be {@code null}.
*/
--
2.36.1

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:9c4f0a22148b5d97d97101771c31f4c13176ee1bc19d311be092d93a4816bb00
size 5160

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:72bfc3189bc337b9f4f311da7909af38f4d8253a8465a984512795db15ab5f4b
size 2786244

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:69b7c0318e2191f7c819be2bb69cdd041f337ed6cbee62d5d2e7582eea5e23ba
size 5232

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:83276c67dfa8084a1f6369fae4ec6fd6b47b31138a970f6f1819c7ad5e250b55
size 2784624

View File

@ -1,3 +1,61 @@
-------------------------------------------------------------------
Wed May 3 11:44:20 UTC 2023 - Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.9.1
* Changes of version 3.8.7:
+ Regression fixes from Maven 3.8.6
+ General fixes
+ Maven Wagon upgrade
* Changes of verson 3.8.8
+ Regression fixes from Maven 3.8.7
+ General fixes
+ Non-functional backports and improvements from 3.9.0
* Changes of version 3.9.0
+ Minimum Java version to use with Maven 3.9.0 is raised to
Java 8.
+ With Java 8, upgrade of several key dependencies became
possible as well.
+ Several backports from Maven 4.x line.
+ Long outstanding issue fixes from Maven 3.x line.
+ Cutting ties with Maven 2 backward compatibility, preparing
grounds for Maven 4.
+ General fixes and improvements.
+ The Maven Resolver transport has changed from Wagon to “native
HTTP”, see Resolver Transport guide.
+ Maven 2.x was auto-injecting an ancient version of
plexus-utils dependency into the plugin classpath, and Maven
3.x continued doing this to preserve backward compatibility.
Starting with Maven 3.9, it does not happen anymore. This
change may lead to plugin breakage. The fix for affected
plugin maintainers is to explicitly declare a dependency on
plexus-utils. The workaround for affected plugin users is to
add this dependency to plugin dependencies until issue is
fixed by the affected plugin maintainer.
+ Mojos are prevented to boostrap new instance of
RepositorySystem (for example by using deprecated
ServiceLocator), they should reuse RepositorySystem instance
provided by Maven instead. See MNG-7471.
+ Each line in .mvn/maven.config is now interpreted as a single
argument. That is, if the file contains multiple arguments,
these must now be placed on separate lines, see MNG-7684.
* Changes of version 3.9.1:
+ Regression fixes from Maven 3.9.0
+ General performance and other fixes
- Changed patches:
* 0001-Adapt-mvn-script.patch
* 0002-Invoke-logback-via-reflection.patch
+ rediff to changed context
* 0004-Remove-dependency-on-powermock.patch
-> 0003-Remove-dependency-on-powermock.patch
* 0007-Fix-build-with-qdox-2.0.1.patch
-> 0004-Fix-build-with-qdox-2.0.1.patch
+ rediff and rename to have the sequence of patches right
- Removed patches:
* 0003-Use-non-shaded-HTTP-wagon.patch
* 0005-Port-to-maven-resolver-1.7.2.patch
* 0006-Restore-DefaultModelValidator-compatibility-with-Mav.patch
+ not needed with 3.9.1
-------------------------------------------------------------------
Mon Aug 29 08:50:39 UTC 2022 - Thorsten Kukuk <kukuk@suse.com>

View File

@ -1,7 +1,7 @@
#
# spec file for package maven
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
@ -20,7 +20,7 @@
%global homedir %{_datadir}/%{name}%{?maven_version_suffix}
%global confdir %{_sysconfdir}/%{name}%{?maven_version_suffix}
Name: maven
Version: 3.8.6
Version: 3.9.1
Release: 0
Summary: Java project management and project comprehension tool
# maven itself is ASL 2.0
@ -35,19 +35,15 @@ Source10: apache-%{name}-%{version}-build.tar.xz
Patch1: 0001-Adapt-mvn-script.patch
# Downstream-specific, avoids dependency on logback
Patch2: 0002-Invoke-logback-via-reflection.patch
Patch3: 0003-Use-non-shaded-HTTP-wagon.patch
Patch4: 0004-Remove-dependency-on-powermock.patch
Patch5: 0005-Port-to-maven-resolver-1.7.2.patch
Patch6: 0006-Restore-DefaultModelValidator-compatibility-with-Mav.patch
Patch7: 0007-Fix-build-with-qdox-2.0.1.patch
Patch3: 0003-Remove-dependency-on-powermock.patch
Patch4: 0004-Fix-build-with-qdox-2.0.1.patch
BuildRequires: ant
BuildRequires: aopalliance
BuildRequires: apache-commons-cli
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-io
BuildRequires: apache-commons-lang3
BuildRequires: apache-commons-logging
BuildRequires: atinject
BuildRequires: cdi-api
BuildRequires: dos2unix
BuildRequires: fdupes
BuildRequires: glassfish-annotation-api
@ -57,14 +53,15 @@ BuildRequires: httpcomponents-client
BuildRequires: httpcomponents-core
BuildRequires: jansi
BuildRequires: javapackages-local
BuildRequires: jboss-interceptors-1.2-api
BuildRequires: jcl-over-slf4j
BuildRequires: jdom2
BuildRequires: maven-resolver-api
BuildRequires: maven-resolver-api >= 1.8.1
BuildRequires: maven-resolver-connector-basic
BuildRequires: maven-resolver-impl
BuildRequires: maven-resolver-named-locks
BuildRequires: maven-resolver-spi
BuildRequires: maven-resolver-transport-file
BuildRequires: maven-resolver-transport-http
BuildRequires: maven-resolver-transport-wagon
BuildRequires: maven-resolver-util
BuildRequires: maven-shared-utils
@ -115,9 +112,9 @@ Summary: Core part of Maven
# dependencies which are not generated automatically, but adding
# everything seems to be easier.
Group: Development/Tools/Building
Requires: aopalliance
Requires: apache-commons-cli
Requires: apache-commons-codec
Requires: apache-commons-io
Requires: apache-commons-lang3
Requires: apache-commons-logging
Requires: atinject
@ -128,7 +125,6 @@ Requires: httpcomponents-client
Requires: httpcomponents-core
Requires: jansi
Requires: javapackages-tools
Requires: jboss-interceptors-1.2-api
Requires: jcl-over-slf4j
Requires: junit
Requires: maven-resolver-api
@ -136,6 +132,8 @@ Requires: maven-resolver-connector-basic
Requires: maven-resolver-impl
Requires: maven-resolver-named-locks
Requires: maven-resolver-spi
Requires: maven-resolver-transport-file
Requires: maven-resolver-transport-http
Requires: maven-resolver-transport-wagon
Requires: maven-resolver-util
Requires: maven-shared-utils
@ -184,9 +182,6 @@ BuildArch: noarch
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
# not really used during build, but a precaution
find -name '*.jar' -not -path '*/test/*' -delete
@ -219,6 +214,8 @@ sed -i "s/distributionName=.*/distributionName=Apache\ Maven/" `find -name build
%pom_remove_dep -r :logback-classic
%pom_xpath_remove pom:parent/pom:relativePath
%{mvn_alias} :maven-resolver-provider :maven-aether-provider
%build
@ -227,10 +224,9 @@ build-jar-repository -s lib \
apache-commons-lang3 \
atinject \
commons-cli \
commons-io \
glassfish-annotation-api \
guava/guava \
guice/google-guice-no_aop \
jboss-interceptors-1.2-api \
guice/google-guice \
jdom2/jdom2 \
maven-resolver/maven-resolver-api \
maven-resolver/maven-resolver-impl \
@ -295,42 +291,40 @@ chmod -x %{buildroot}%{homedir}/bin/*.cmd %{buildroot}%{homedir}/bin/*.conf
# Transitive deps of wagon-http, missing because of unshading
build-jar-repository -p %{buildroot}%{homedir}/lib \
cdi-api/cdi-api \
aopalliance \
apache-commons-lang3 \
atinject \
commons-cli \
commons-codec \
commons-io \
apache-commons-lang3 \
glassfish-annotation-api \
guava/guava \
guice/google-guice-no_aop \
guice/google-guice \
httpcomponents/httpclient \
httpcomponents/httpcore \
jansi/jansi \
jboss-interceptors-1.2-api \
jsoup/jsoup \
atinject \
slf4j/jcl-over-slf4j \
glassfish-annotation-api \
maven-resolver/maven-resolver-api \
maven-resolver/maven-resolver-connector-basic \
maven-resolver/maven-resolver-impl \
maven-resolver/maven-resolver-named-locks \
maven-resolver/maven-resolver-spi \
maven-resolver/maven-resolver-transport-file \
maven-resolver/maven-resolver-transport-http \
maven-resolver/maven-resolver-transport-wagon \
maven-resolver/maven-resolver-util \
maven-shared-utils/maven-shared-utils \
maven-wagon/http-shared \
org.eclipse.sisu.inject \
org.eclipse.sisu.plexus \
plexus/plexus-cipher \
plexus-containers/plexus-component-annotations \
plexus/interpolation \
plexus/plexus-sec-dispatcher \
plexus/utils \
slf4j/api \
maven-wagon/file \
maven-wagon/http \
maven-wagon/http-shared \
maven-wagon/provider-api
maven-wagon/provider-api \
org.eclipse.sisu.inject \
org.eclipse.sisu.plexus \
plexus/plexus-cipher \
plexus/interpolation \
plexus/plexus-sec-dispatcher \
plexus/utils \
plexus-containers/plexus-component-annotations \
slf4j/api \
slf4j/jcl-over-slf4j
cp %{buildroot}%{_javadir}/%{name}/*.jar %{buildroot}%{homedir}/lib/